# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AgentListParams"]


class AgentListParams(TypedDict, total=False):
    limit: int
    """Maximum number of items to return."""

    offset: int
    """Number of items to skip."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AgentCreateResponse", "RequestMetadata"]


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentCreateResponse(BaseModel):
    """Response after creating a new agent."""

    agent_id: str
    """Unique identifier of the created agent."""

    message: str
    """Human-readable result message."""

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel

__all__ = [
    "AgentRunResponse",
    "AdditionalMetadata",
    "ResponseResponseItem",
    "ResponseResponseItemToolcall",
    "Usage",
    "UsageCreditsCharged",
    "RequestMetadata",
]


class AdditionalMetadata(BaseModel):
    thread_id: str


class ResponseResponseItemToolcall(BaseModel):
    args: Dict[str, object]

    name: str


class ResponseResponseItem(BaseModel):
    llmresponse: str

    reasoning: str

    toolcalls: List[ResponseResponseItemToolcall]

    toolresponse: List[str]


class UsageCreditsCharged(BaseModel):
    agent_name: str

    credit_consumed: int

    number_of_runs: int


class Usage(BaseModel):
    credits_charged: List[UsageCreditsCharged]

    total_credits_charged: int


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentRunResponse(BaseModel):
    additional_metadata: AdditionalMetadata

    response: List[Dict[str, ResponseResponseItem]]

    usage: Usage

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AgentRetrieveResponse", "UploadedBy", "RequestMetadata"]


class UploadedBy(BaseModel):
    """Information about the agent creator."""

    user_email: Optional[str] = None
    """Email of the user who created the agent."""

    user_id: Optional[str] = None
    """ID of the user who created the agent."""


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentRetrieveResponse(BaseModel):
    """
    Agent detail returned by the get-agent endpoint, includes a note about YAML config.
    """

    agent_id: str
    """Unique identifier of the agent."""

    description: str
    """Description of the agent."""

    hosted_to: str
    """Deployment target: 'AgentStore' or 'Organization'."""

    is_creator: bool
    """Whether the requesting user is the creator of this agent."""

    name: str
    """Name of the agent."""

    uploaded_by: UploadedBy
    """Information about the agent creator."""

    yaml_configuration: str
    """A note directing the user to the download endpoint for the YAML configuration."""

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from .._types import FileTypes

__all__ = ["AgentUpdateInfoParams"]


class AgentUpdateInfoParams(TypedDict, total=False):
    agent_id: Required[str]
    """The ID of the agent to update."""

    agent_icon: Optional[FileTypes]
    """New agent icon (512x512 pixels)."""

    deploy_to: Optional[str]
    """New deployment target: 'AgentStore' or 'Organization'."""

    description: Optional[str]
    """New description for the agent."""

    name: Optional[str]
    """New name for the agent."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AgentUpdateInfoResponse", "RequestMetadata"]


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentUpdateInfoResponse(BaseModel):
    """Simple response containing a message string."""

    message: str
    """Human-readable result message."""

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .agent_run_params import AgentRunParams as AgentRunParams
from .agent_list_params import AgentListParams as AgentListParams
from .agent_test_params import AgentTestParams as AgentTestParams
from .auth_login_params import AuthLoginParams as AuthLoginParams
from .agent_run_response import AgentRunResponse as AgentRunResponse
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .agent_delete_params import AgentDeleteParams as AgentDeleteParams
from .agent_list_response import AgentListResponse as AgentListResponse
from .agent_create_response import AgentCreateResponse as AgentCreateResponse
from .agent_delete_response import AgentDeleteResponse as AgentDeleteResponse
from .agent_validate_params import AgentValidateParams as AgentValidateParams
from .agent_retrieve_response import AgentRetrieveResponse as AgentRetrieveResponse
from .agent_validate_response import AgentValidateResponse as AgentValidateResponse
from .agent_bulk_delete_params import AgentBulkDeleteParams as AgentBulkDeleteParams
from .agent_reconfigure_params import AgentReconfigureParams as AgentReconfigureParams
from .agent_update_info_params import AgentUpdateInfoParams as AgentUpdateInfoParams
from .agent_bulk_delete_response import AgentBulkDeleteResponse as AgentBulkDeleteResponse
from .agent_reconfigure_response import AgentReconfigureResponse as AgentReconfigureResponse
from .agent_update_info_response import AgentUpdateInfoResponse as AgentUpdateInfoResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AgentValidateResponse", "RequestMetadata"]


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentValidateResponse(BaseModel):
    message: str
    """Detailed message about the validation outcome."""

    status: str
    """The result status of the validation."""

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""

    suggestion: Optional[str] = None
    """Optional suggestion if any errors were found."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["AgentBulkDeleteResponse", "RequestMetadata"]


class RequestMetadata(BaseModel):
    """Response metadata including timestamp and request ID."""

    request_id: Optional[str] = None
    """Unique request identifier for tracing and support."""


class AgentBulkDeleteResponse(BaseModel):
    """Response after deleting multiple agents."""

    message: str
    """Summary of the deletion operation."""

    deleted_ids: Optional[List[str]] = None
    """IDs of the agents that were successfully deleted."""

    request_metadata: Optional[RequestMetadata] = None
    """Response metadata including timestamp and request ID."""
